@@ -91,8 +91,9 @@ public:
 	    *invSelection,//!< QAction invert selection
             *hideBeLo;//!< hide/show  BEDE and LONE objects
     QToolButton *enviButt;//!< Button to clear the envi -ronment.
+    QToolButton *enviSelect;//!< Button to select the envi -ronment.
     QList<V3>enviPositions;//!<List of atom postions of an envi-ronment.
-    QList<int>enviKat;//!< List of categorys of contacts in an envi-ronment.
+    QList<int>enviKat;//!< List of categorie:qs of contacts in an envi-ronment.
     V3 enviP0;//!< coordinate used for envi.
     QMenu *sfacMenu;//!< a sub menu to change the element of a specified atom.
     QStringList labs;//!< Labels for an envi-ronment list.
@@ -182,6 +183,7 @@ public slots:
     void rotCenter();
     void saveOrientation();
     void saveOrientation(QString fn);
+    void selectEnvi();
     void selectPair(const QString &s);
     void selectResiByNr(int nr);
     void selectThisFragment();
