@@ -333,9 +333,10 @@ void CodeEditor::afixHighlightAreaPaintEvent(QPaintEvent *event){
       //          Qt::white;
       break;
   case 1: color=Qt::darkGreen;break;
-  case 2: color=QColor("blueviolet");
-      //printf("%d\n",parenthesis3.at(blockNumber));
-      if (parenthesis3.at(blockNumber)) break;
+  case 2: 
+      if (parenthesis3.at(blockNumber)) color=QColor("blueviolet"); 
+      else color=Qt::red;
+      break;          
   default: color=Qt::red;break;
   }
   switch (parenthesis2.at(blockNumber)){ 
