@@ -90,6 +90,7 @@ public:
 signals:
     void findInStructure(const QString &);//!< findInStructure is emitted by a context menu to select and center an atom in the OpenGL representation of the structure.  
     void electInStructure(const QString &);//!< electInStructure is emitted by a context menu to select atoms found in the editor text selection in the OpenGL representation.
+    void sortInStructure(const QString &);//!< sortInStructure is emitted by a context menu to sort atoms found in the editor text selection.
     void search(const QString&);//!< searches a QString in the editor. Used to point the cursor to the atom clicked in the OpenGL representation.
     void deleteSelected();//!< deleteSelected is emitted by a context menu to select and delete atoms found in the editor text selection in the OpenGL representation.
 protected:
@@ -107,6 +108,7 @@ public slots:
     void insertCompletion(const QString &completion);//!< insertCompletion inserts the text selected in the completer. @param completion selected text of the completer.
     void searchInStructure();//!< Select and center an atom in the OpenGL representation of the structure.
     void selectInStructure();//!< Select atoms found in the editor text selection in the OpenGL representation.
+    void ortInStructure();//!< sortInStructure is emitted by a context menu to sort atoms found in the editor text selection.
     void lineNumberToggled(QMouseEvent *event);//!< when the LineNumberArea is clicked the comment state of the secified line is toggled.
     void remark(int line);//!< toggles the comment state of the secified line. @param line The line number in file
     void toggleRemarks();//!< toggleRemarks toggles the comment state of the selected lines.
