@@ -256,6 +256,8 @@ void DSREditWindow::clearAll(){
   atomsEdit->clear();
   restrEdit->clear();
   restrEdit->append("Add at least one restraint here. (And delete this text)");
+  addButton->setDisabled(true);  // Otherwise, it is possible to create a damaged fragment.
+  updateButton->setDisabled(true);
   myedgl->clear_molecule();
 }
 
