@@ -44,6 +44,7 @@ DSRGlWindow::DSRGlWindow(QWidget *parent, Molecule *m,
   mole.bindatoms.clear();
   mole.selectedatoms.clear();
   mole.showatoms.clear();
+  dsrLabelColor = QColor("white");
   V3 nl(0,0,0);
   mole.cell.trans.append(nl);
   mole.cell.symmops.append(Matrix(1,0,0, 0,1,0, 0,0,1));
@@ -130,7 +131,7 @@ void DSRGlWindow::draw(){
   mole.atoms(xd, 50);
   mole.bonds(bonds);
   glEnable(GL_COLOR_MATERIAL);
-  glColor3f(1.0f,1.0f,1.0f);  // The label color
+  qglColor(dsrLabelColor);  // The fragment label color
   glClear( GL_DEPTH_BUFFER_BIT);
   for (int i=0; i<xd.size(); i++){
       GLdouble in[4], out[4];
@@ -181,7 +182,7 @@ void DSRGlWindow::draw(){
       mole.dbond(fitabonds);
       mole.lbond();
       if (showFitLabel->isChecked()){
-        glColor3f(0.0f,0.0f,0.5f);  // The label color
+        qglColor(QColor(0, 0, 175));  // The surrounding atoms label color
         for (int i=0; i<fita.size(); i++){
           renderText( fita.at(i).pos.x, fita.at(i).pos.y, fita.at(i).pos.z, fita.at(i).Label, myFont);
         }
@@ -273,9 +274,12 @@ void DSRGlWindow::clear_molecule()
   updateGL();
 }
 
-void DSRGlWindow::display_fragment(DSRMol frag)
+void DSRGlWindow::display_fragment(DSRMol frag, bool clear_sel)
 { //! uses a QStringlist of atoms from DSR and fills
   //! them into a MyAtom. MyAtom is then drawn in OpenGL
+  //! @param The fragment from DSR
+  //! @param clear_sel if enabled, the selected atoms are cleared
+  //! before drawing the molecule
   V3 mid = V3(0,0,0);
   MyAtom newAtom;
   newAtom.part = 0;
@@ -287,7 +291,10 @@ void DSRGlWindow::display_fragment(DSRMol frag)
   bonds.clear();
   fita.clear();
   fitabonds.clear();
-  selFragAt.clear();
+  // Do not clear the selection during invert:
+  if (clear_sel) {
+    selFragAt.clear();
+  }
   if (frag.atoms.isEmpty()) {
     return;
   }
@@ -311,6 +318,20 @@ void DSRGlWindow::display_fragment(DSRMol frag)
   updateGL();
 }
 
+
+void DSRGlWindow::set_label_color() {
+    //! Sets the label color. The default color was not visible
+    //! for white or yellow atoms.
+    QColor lc= QColorDialog::getColor(QColor(6, 167, 222), this);
+    if (lc.isValid()) {
+        dsrLabelColor=lc;
+    } else {
+        dsrLabelColor = QColor("white");
+    }
+    updateGL();
+}
+
+
 void DSRGlWindow::mousePressEvent(QMouseEvent *event){
   //! Handles the mousePressEvents in the 3D view.
   //! Atoms are selectable if showFit is not NULL.
@@ -319,34 +340,41 @@ void DSRGlWindow::mousePressEvent(QMouseEvent *event){
   //! With more than three atoms, the first selection will be removed.
   moux=event->pos().x();
   mouy=event->pos().y();
-  // Has to be after moux/mouy, otherwise zoom is strange:
-  if (showFit == NULL) return;  // <-prevents selection of atoms in edit window
-  double nahda=200.0,da=0;
-  int nahdai=-1;
-  for (int j=0; j<xd.size();j++){
-    if (xd.at(j).hidden) continue;
-    da=(((xd.at(j).screenX-event->x())*( xd.at(j).screenX-event->x()))+
-        ((xd.at(j).screenY-event->y())*( xd.at(j).screenY-event->y())));
-    nahdai=(da<nahda)?j:nahdai;
-    nahda=qMin(nahda,da);
+  if((event->buttons() == Qt::RightButton && event->modifiers() == Qt::ControlModifier)){
+      QMenu *menu = new QMenu("");
+      menu->addAction(QString("Set label color"), this, SLOT(set_label_color()));
+      menu->exec(QCursor::pos());
   }
-  if ((nahdai >- 1) && (nahdai < xd.size())){
-    // This might be a good idea in the first place, but results in wired behavior:
-    //if (selFragAt.contains(xd[nahdai])) {
-    //    return;
-    //}
-    selFragAt.append(xd[nahdai]);
-    if (selFragAt.size() > 3) selFragAt.removeFirst();
-    updateGL();
-    if (selFragAt.size() == 3) {
-      source_atoms = QString("%1 %2 %3")
-                      .arg(selFragAt.at(0).Label)
-                      .arg(selFragAt.at(1).Label)
-                      .arg(selFragAt.at(2).Label);
-      emit sourceStringChanged();
+  if (event->buttons() == Qt::LeftButton) {
+    // Has to be after moux/mouy, otherwise zoom is strange:
+    if (showFit == NULL) return;  // <-prevents selection of atoms in edit window
+    double nahda=200.0, da=0;
+    int nahdai=-1;
+    for (int j=0; j<xd.size();j++){
+      if (xd.at(j).hidden) continue;
+      da=(((xd.at(j).screenX-event->x())*( xd.at(j).screenX-event->x()))+
+          ((xd.at(j).screenY-event->y())*( xd.at(j).screenY-event->y())));
+      nahdai=(da<nahda)?j:nahdai;
+      nahda=qMin(nahda,da);
     }
+    if ((nahdai >- 1) && (nahdai < xd.size())){
+      // This might be a good idea in the first place, but results in wired behavior:
+      //if (selFragAt.contains(xd[nahdai])) {
+      //    return;
+      //}
+      selFragAt.append(xd[nahdai]);
+      if (selFragAt.size() > 3) selFragAt.removeFirst();
+      updateGL();
+      if (selFragAt.size() == 3) {
+        source_atoms = QString("%1 %2 %3")
+                        .arg(selFragAt.at(0).Label)
+                        .arg(selFragAt.at(1).Label)
+                        .arg(selFragAt.at(2).Label);
+        emit sourceStringChanged();
+      }
+    }
+    makeInfo();
   }
-  makeInfo();
 }
 
 void DSRGlWindow::makeInfo(){
@@ -464,13 +492,13 @@ void DSRGlWindow::tryfit(){
   // m_molecule->showatoms was m_molecule->asymm before, but showatoms is needed for disorder
   // around special positions:
   for (int i=0; i<m_molecule->showatoms.size(); i++) {
-    fita.append( m_molecule->showatoms[i]);
+    fita.append(m_molecule->showatoms[i]);
     fita.last().pos+=-1.0*(m_molecule->selectedatoms.at(0).pos); 
     fita.last().pos=fita.last().pos*amat;
     fita.last().pos=fita.last().pos*bmat;
     fita.last().pos+=selFragAt.at(0).pos;
     fita.last().part=1;
-    if (Norm (fita.last().pos) > 12) {  // 4 Angstroem cut of (3*4=12)
+    if (Norm (fita.last().pos) > 12) {  // 4 Angstroem cut-off (3*4=12)
       fita.removeLast();
     }
   }  
@@ -492,6 +520,6 @@ void DSRGlWindow::tryfit(){
       dmin=(d<dmin)?d:dmin;
     }
     printf("%-8s <==> %-8s %f\n", xd.at(i).Label.toStdString().c_str(),
-           m_molecule->showatoms.at(imin).Label.toStdString().c_str(),sqrt(dmin));
+           m_molecule->showatoms.at(imin).Label.toStdString().c_str(), sqrt(dmin));
   }
 }
