@@ -11,6 +11,7 @@
 
 #include <QtGui>
 #include <QDir>
+#include <QNetworkAccessManager>
 #include "dsrgui.h"
 #include "window.h"
 #include "dsrglwindow.h"
@@ -18,9 +19,9 @@
 #include "itsme.h"
 
 #ifdef Q_WS_WIN32
-   QString mysystem = "win";
+   static const QString mysystem = "win";
 #else
-   QString mysystem = "unix";
+   static const QString mysystem = "unix";
 #endif
 
 /*
@@ -32,15 +33,15 @@ Explanations
 - This GUI uses that information to provide a convenient interface for DSR.
 - DSR is controlled by a special command in the SHELXL res file starting with REM DSR ...
   and by commandline options.
-- A special not documented command line option is -ah. It tells DSR to print the
-  information about a given fragment name in a special format for this GUI.
+- A special command line option -ah tells DSR to print the information about a
+  fragment in a special format for this GUI.
   It is a list of html-like tags <tag> data </tag> with ;; separated values containing for
   example the unit cell information and coordinates of the fragment. The first line
   contains the version number of DSR.
 - The GUI first runs dsr with -lc to get a list of all fragment names in the database.
   A mouse click on a fragment in the list invokes "dsr -ah name" to get the details of
-  this special fragment (struct DSRMol). This details are also used to edit the fragment
-  (edit fragment button).
+  the selected fragment (and stores it in struct DSRMol). This details are also used to
+  edit the fragment ("edit fragment" button).
 - The text widget below the search field displays some status output from DSR,
   especially the text output from DSR during the fragment transfer/fit to the target structure.
 
@@ -58,8 +59,7 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   m_shelxle = parent;
   m_molecule = mole;
   m_shelxlPath = shelxlPath;
-  // Qt::WindowStaysOnTopHint makes no sense here, because of the update info window
-  setWindowFlags(Qt::Window);
+  this->setWindowFlags(Qt::Window);
   setWindowTitle(QString(tr("DSR GUI")));
   if (mysystem == QString("win")) {
     dsrpath = getDSRDir()+"/dsr.bat";
@@ -68,7 +68,8 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
     dsrpath = QDir::cleanPath(getDSRDir()+"/dsr");
     dsr_db_path = QDir::cleanPath(getDSRdbDir());
   }
-  dsrVersion.clear();
+  this->hide();
+  dsrVersion = "";
   replace = false;
   norefine = false; // this has to stay here
   runext = false;
@@ -126,6 +127,7 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   resiTextLabel->setText(*resnumbertext);
   outtext = new QTextEdit;
   info = new QTextBrowser;
+  this->move(-this->width(), -this->height());
   info->hide();
   info->setMinimumWidth(235);
   //info->setMaximumWidth(235);
@@ -227,6 +229,7 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   exportFragButton->setEnabled(false);
   buttonLayout->addWidget(splitButton);
   splitButton->setDisabled(true);
+  splitButton->hide();  // there is no DSR version that can do this until now.
   buttonLayout->addWidget(editButton);
   buttonLayout->addWidget(openLastButton);
   // tooltips:
@@ -255,21 +258,18 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   SearchInp->setFocus();
   // Has to be here, otherwise fragmentTableView is not initialized:
   QItemSelectionModel *sm = fragmentTableView->selectionModel();
-  this->move(m_shelxle->width(), 30);  // prevents flickering
-  this->show(); // has to be directly before move(), otherwise the window has wrong position
   this->move(m_shelxle->width()-this->width()-30, 30);
+  this->show();
   if (!(sm == 0x0)){  // prevents error about missing connection if DSR is not present
     connect(sm, SIGNAL(currentRowChanged(QModelIndex,QModelIndex)),
         this, SLOT(setFragName(QModelIndex)), Qt::UniqueConnection);
   }
-  outtext->append(tr("\n* Please pick a fragment first."));
-  outtext->append(tr("* Then select at least three atoms from "
-                    "the main structure and the fragment respectively. (STRG+click)"));
-  outtext->append(tr("* Do not forget to apply a part number and free "
-                     "variable in case of disorder."));
-  outtext->append(tr("* The fragment will be placed after FVAR in the SHELX file."));
-  if (!dsrVersion.isEmpty()) {
+  this->resize(this->width()-2, this->height()-2);  // a trick to redraw the gl windows
+  if (!(dsrVersion.toLatin1() == "0")) {
     outtext->append(QString("\nFound DSR version %1.").arg(dsrVersion));
+    if (dsrVersion.toInt() > 9999) {  // To be changed later
+        splitButton->show();  // logic turned, because a non-replying web server turned this button on
+    }
   }
 }
 
@@ -371,11 +371,44 @@ void DSRGui::getVersionFromServer() {
     reply = net_manager->get(request);
   }
 
+bool DSRGui::runTCPServer() {
+  //! Socket server to get messages from DSR. Might be used in future.
+  tcpServer = new QTcpServer(this);
+  //connect(tcpServer, SIGNAL(newConnection()), this, SLOT(ReadClientData()));
+  if (!tcpServer->listen(QHostAddress::LocalHost, 51234)) {
+      tcpServer->close();
+      return false;
+  } else {
+    if (tcpServer->waitForNewConnection()) {
+      if (tcpServer->hasPendingConnections()) {
+        ReadClientData();
+      }
+    }
+  }
+  return true;
+}
+
+void DSRGui::ReadClientData() {
+  //! Reads DSR client data from a tcp soccet connection.
+  QByteArray data_buffer;
+  QTcpSocket *clientConnection = tcpServer->nextPendingConnection();
+  connect(clientConnection, SIGNAL(readyRead()), clientConnection, SLOT(deleteLater()));
+  // this wait is essential to retrieve data:
+  clientConnection->waitForReadyRead();
+  while (clientConnection->bytesAvailable() > 0) {
+      data_buffer = clientConnection->readAll();
+  }
+  //close tcpServer after reading data:
+  tcpServer->deleteLater();
+  outtext->append(data_buffer);
+  //dsrResulttext.append(data_buffer);
+}
+
 void DSRGui::isDSRUpToDate(QNetworkReply* reply) {
   /*
    *! Displays a warning if the current DSR version is too old.
   */
-  QString latestRev_str=reply->readAll();
+  QString latestRev_str = reply->readAll();
   bool ok;
   bool ok2;
   QMessageBox info;
@@ -385,10 +418,7 @@ void DSRGui::isDSRUpToDate(QNetworkReply* reply) {
   if (dsrv < 193) {  // This is the first version with self-update mechanism
     updateButton->hide();
   }
-  if (dsrv < 999) {  // To be changed later (probably DSR v209)
-      splitButton->hide();
-  }
-  int latestrev_int=latestRev_str.toInt(&ok,10);
+  int latestrev_int = latestRev_str.toInt(&ok,10);
   if ((ok&&ok2)&&(latestrev_int)>(dsrv)){
     info.setText(QString(
                    "<h3>You should probably update DSR!</h3>"
@@ -420,7 +450,7 @@ void DSRGui::updateTarget() {
 
 void DSRGui::writeFavorites(QString name) {
   //! Stores favorites in dsrgui.ini
-  QSettings dsr_settings( QSettings::IniFormat, QSettings::UserScope ,PROGRAM_NAME,"dsrgui" );
+  QSettings dsr_settings( QSettings::IniFormat, QSettings::UserScope, PROGRAM_NAME, "dsrgui" );
   dsr_settings.beginGroup("LastFragment");
   dsr_settings.setValue("last", name);
   dsr_settings.endGroup();
@@ -428,13 +458,16 @@ void DSRGui::writeFavorites(QString name) {
 
 QString DSRGui::loadFavoriteFragment() {
   //! Loads Favorites from dsrgui.ini
-  QSettings dsr_settings( QSettings::IniFormat, QSettings::UserScope ,PROGRAM_NAME,"dsrgui" );
+  QSettings dsr_settings( QSettings::IniFormat, QSettings::UserScope, PROGRAM_NAME, "dsrgui" );
   dsr_settings.beginGroup("LastFragment");
   QString last = dsr_settings.value("last").toString();
   dsr_settings.endGroup();
   if (last == QString("cf6")) {
     splitModeBox->show();
   }
+  if (last == QString("")) {
+    last = QString("benzene");
+  }
   return last;
 }
 
@@ -470,7 +503,14 @@ QStringList DSRGui::which(QString programName) {
 void DSRGui::checkForDSRexecutable(QSplashScreen *splash) {
   //! list fragments only if the path of dsr installation is found:
   if (QFile::exists(dsrpath)) {
-    listDSRdbFragments("None");
+    if (listDSRdbFragments("None")) {
+      outtext->append(tr("\n* Please pick a fragment first."));
+      outtext->append(tr("* Then select at least three atoms from "
+                        "the main structure and the fragment respectively. (STRG+click)"));
+      outtext->append(tr("* Do not forget to apply a part number and free "
+                         "variable in case of disorder."));
+      outtext->append(tr("* The fragment will be placed after FVAR in the SHELX file."));
+    }
   } else {
     outtext->clear();
     outtext->append(QString(tr("Unable to find DSR executable."
@@ -530,6 +570,10 @@ QString DSRGui::textWrap(QString inText, int length, QString subsequent_indent)
 bool DSRGui::open_last_fileversion() {
     //! Opens the last res file version before the last DSR action from the save history (./Shelxsaves/SAVEHIST)
     QFileInfo fi(m_shelxle->dirName);
+    if (!fi.isReadable()) {
+        outtext->append("No last .res file found to load.");
+        return false;
+    }
     QFile currentpath(fi.absolutePath());
     QString saveHistFileName=QString("%1/%2saves/SAVEHIST").arg(currentpath.fileName()).arg(PROGRAM_NAME);
     QFile savehist(saveHistFileName);
@@ -747,18 +791,16 @@ bool DSRGui::getFragmentHeader(QString frag) {
   outtext->clear();
   QString *rawheader = new QString;
   QStringList *headerlist = new QStringList;
-  QProcess dsr;
-  dsr.setProcessChannelMode(QProcess::MergedChannels);
-  dsr.start(dsrpath, QStringList() << "-ah" << frag);
-  dsr.closeWriteChannel();
-  if (!dsr.waitForFinished(5000))
-  {
+  QString options = " -ah " + frag;
+  dsrResulttext.clear();
+  runDSR(options);
+  if (dsrResulttext.isEmpty()) {
     outtext->clear();
     outtext->append(tr("Unable to run DSR."));
     editButton->setDisabled(true); // editing the empty header would crash ShelXle
     return false;
   } else {
-    rawheader->append(dsr.readAll());
+    rawheader->append(dsrResulttext);
   }
   // in this case no fragment list returned. Hence, we have an error.
   if (!rawheader->contains(";;")) {
@@ -843,9 +885,10 @@ void DSRGui::activateFitButton(void) {
 
 
 void DSRGui::combineOptionstext(void) {
-//! combines all options to a single DSR command line
-//! This method gets invoked if optionTextChanged signal is emmitted
-// Idea for later: QString("%1").arg(m_shelxle->fvarCntr.value(2))
+  //! combines all options to a single DSR command line
+  //! This method gets invoked if optionTextChanged signal is emmitted
+  combiDSRline.clear();
+  // Displays error messages from DSR:
   if (!outtext->toPlainText().contains("***")) {
     outtext->clear();
   } //else {
@@ -863,11 +906,11 @@ void DSRGui::combineOptionstext(void) {
        (fragmentNameTag == QString("cf6")) ||
        (fragmentNameTag == QString("cf9")) ) {
     this->cf3 = true;
-    residueOptionsBox->setChecked(false);
     rigidBox->setDisabled(true);
     invertFragBox->setDisabled(true);
     runExtBox->setDisabled(true);
     replaceModeBox->setDisabled(true);
+    residueOptionsBox->setDisabled(true);
     if (splitModeBox->isChecked() ) {
       split = "SPLIT";
     }
@@ -878,6 +921,7 @@ void DSRGui::combineOptionstext(void) {
     invertFragBox->setDisabled(false);
     runExtBox->setDisabled(false);
     replaceModeBox->setDisabled(false);
+    residueOptionsBox->setDisabled(false);
   }
   target_atoms = getSelectedAtomsList();
   QString putreplace = QString("PUT ");
@@ -898,7 +942,7 @@ void DSRGui::combineOptionstext(void) {
     mygl->source_atoms = "";
   }
   QString resistr = "RESI ";
-  if (!residueOptionsBox->isChecked()) {
+  if (!residueOptionsBox->isChecked() || !residueOptionsBox->isEnabled()) {
     resistr = "";
     resiTextLabel->setText("");
   } else {
@@ -939,10 +983,10 @@ void DSRGui::setResiClass(QString rclass) {
 
 void DSRGui::setFragName(QModelIndex name) {
 //! set the fragment name variable
-  outtext->clear();
+  //outtext->clear();
   fragmentNameTag = name.sibling(name.row(), 0).data().toString();
   writeFavorites(fragmentNameTag);
-  outtext->clear();
+  //outtext->clear();
   if (!getFragmentHeader(fragmentNameTag)) {
     // In this case, the most important thing is missing
     return;
@@ -1036,18 +1080,38 @@ void DSRGui::invertFrag(bool checked) {
   } else {
     this->invert = false;
   }
+  V3 v1 = V3(-1,  0,  0);
+  V3 v2 = V3( 0, -1,  0);
+  V3 v3 = V3( 0,  0,  1);
+  //rotation matrix to rotate the selection 180deg.
+  // for less disturbance of the inverted view:
+  Matrix rmat = Matrix(v1, v2, v3);
   // Invert the OpenGL coordinates:
-  float coord;
+  double coord;
   int index;
   index = 0;
   foreach(QStringList line, header->atoms) {
     for (int n = 2; n<5; n++) {
-      coord = line[n].toFloat();
+      coord = line[n].toDouble();
+      // rotate fragment 180 deg.
+      if ((n == 2) | (n == 3)) {
+        coord = coord * -1;
+      }
       header->atoms[index][n] = QString("%1").arg(-coord);
     }
     index = index+1;
   }
-  mygl->display_fragment(*header);
+  //Also invert the selection of the atoms:
+  for (int n=0; n<mygl->selFragAt.size(); n++) {
+    mygl->selFragAt[n].pos = mygl->selFragAt[n].pos * rmat;
+    mygl->selFragAt[n].pos.x *= -1;
+    mygl->selFragAt[n].pos.y *= -1;
+    mygl->selFragAt[n].pos.z *= -1;
+  }
+  mygl->display_fragment(*header, false);
+  // This mouse press hack reactivates the fit overlay after inversion:
+  QMouseEvent ev ((QEvent::MouseButtonPress), QPoint(0, 0), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+  mygl->mousePressEvent(&ev);
 }
 
 void DSRGui::rigid_group(bool checked)
@@ -1069,17 +1133,13 @@ bool DSRGui::exportFrag(QString dirname) {
       outtext->append("No fragment chosen. Doing nothing!");
       return false;
   }
-  QProcess dsr;
-  dsr.setProcessChannelMode(QProcess::MergedChannels);
-  dsr.start(dsrpath, QStringList() << QString("-e") << fragmentNameTag);
-  dsr.closeWriteChannel();
-  outtext->clear();
-  if (!dsr.waitForFinished()) {
+  //outtext->clear();
+  QString options = QString(" -e ") + fragmentNameTag;
+  dsrResulttext.clear();
+  runDSR(options, true, dirname);
+  if (dsrResulttext.isEmpty()) {
     outtext->append("Unable to start DSR.");
-    outtext->append(dsr.readAll());
     return false;
-  } else {
-    outtext->append(dsr.readAll());
   }
   return true;
 }
@@ -1153,7 +1213,6 @@ bool DSRGui::fitDSR() {
   }
   info->hide(); // Even if the fit does not work, I want to hide it to better see the output
   QString option;
-  QString target_atoms_tmp;
   QString source_atoms_tmp = mygl->source_atoms;
   if ((m_molecule->selectedatoms.size() != 3) && !cf3) {
     //outtext->clear();
@@ -1168,7 +1227,6 @@ bool DSRGui::fitDSR() {
     return false;
   }
   target_atoms = getSelectedAtomsList();
-  target_atoms_tmp = target_atoms;
   bool ok;
   int dsrv = dsrVersion.toInt(&ok, 10);
   if (ok && dsrv < 200) {
@@ -1177,17 +1235,16 @@ bool DSRGui::fitDSR() {
     if ( target_atoms.contains(QString(">>"))) {
       outtext->clear();
       outtext->append(QString("<font color=red><b>Symmetrie generated atoms not allowed as target! <br><br>"
-                              "You might want to copy them (in a negative part).</b></font>"));
+                              "Please update DSR.</b></font>"));
       return false;
     }
   }
   emit optionTextChanged();
-  bool save_sucess = m_shelxle->fileSave();
+  bool save_sucess = m_shelxle->fileSave(true, false);
   if (!save_sucess) {
     outtext->append("Could not save the instruction file!");
     return false;
   }
-  target_atoms = target_atoms_tmp;
   QStringList *reslist = new QStringList;
   reslist->append(readResfile());
   mygl->source_atoms = source_atoms_tmp;
@@ -1200,7 +1257,6 @@ bool DSRGui::fitDSR() {
   QString wrappedDSRLine = textWrap(combiDSRline, 75);
   m_shelxle->insertDSRLine(wrappedDSRLine, DSRposition, previousLines);
   delete reslist;
-  dsrResulttext.clear();
   if (rigid) {
     option = "-g ";
   } else {
@@ -1262,35 +1318,58 @@ void DSRGui::updateDSR(void) {
   this->runDSR(option);
 }
 
-bool DSRGui::runDSR(QString option) {
-    QFileInfo resfip(m_shelxle->dirName);
-    QProcess dsr;
-    dsr.setProcessChannelMode(QProcess::MergedChannels);
-    dsr.closeWriteChannel();
-    dsr.setWorkingDirectory(resfip.absolutePath());
-    dsr.start(dsrpath, option.split(" ", QString::SkipEmptyParts));
-    if (!dsr.waitForFinished())
-    {
-      dsrResulttext.append("Unable to start DSR.");
-      dsrResulttext.append(dsrpath);
-      dsrResulttext.append(dsr.readAll());
-      return false;
-    } else {
-      dsrResulttext.append(dsr.readAll());
+bool DSRGui::runDSR(QString option, bool showresults, QString workdir) {
+  //! runs DSR with options and shows the results in outtext if desired.
+  dsrResulttext.clear();
+  outtext->clear();
+  QProcess dsr;
+  QFileInfo resfip;
+  if (workdir.isEmpty()) {
+    // workdir can be the export (fragment) directory for example.
+    resfip.setFile(m_shelxle->dirName);
+    if (!resfip.absolutePath().isEmpty()) {
+      // Need to check if path is not empty, because en empty path would cause dsr.start() to fail.
+      // absolutePath() truncates the last path part even though its C:\foo\bar --> C:\foo
+      dsr.setWorkingDirectory(resfip.absolutePath());
     }
+  } else {
+    resfip.setFile(workdir);
+    dsr.setWorkingDirectory(resfip.absoluteFilePath());
+  }
+  dsr.setProcessChannelMode(QProcess::MergedChannels);
+  dsr.closeWriteChannel();
+  dsr.start(dsrpath, option.split(" ", QString::SkipEmptyParts));
+  if (!dsr.waitForFinished()) {
+    outtext->append("Unable to start DSR.");
+    outtext->append(dsrpath + " " + option);
+    outtext->append(dsr.readAll());
+    return false;
+  } else {
+    dsrResulttext.append(dsr.readAll());
+    //qDebug() << dsrResulttext;
+  }
+  /*
+  if (dsrResulttext.isEmpty()) {
+    bool socket = runTCPServer();
+    if (!socket) {
+      outtext->append("Unable read DSR output.");
+    }
+  } */
+  if (showresults) {
     // Display the results:
-    outtext->clear();
+    //outtext->clear();
     outtext->append(combiDSRline);
     outtext->append(dsrResulttext);
-    this->show();
-    this->raise();
-    this->activateWindow();
-    return true;
+  }
+  this->show();
+  this->raise();
+  this->activateWindow();
+  //qDebug() << dsrResulttext;
+  return true;
 }
 
 void DSRGui::searchFragment(QString searchName) {
   //! Searches for fragments in the database
-  QString *result = new QString;
   if ((searchName.length() < 2) && (searchName.length() > 0)){
     return;
   }
@@ -1302,21 +1381,12 @@ void DSRGui::searchFragment(QString searchName) {
     }
     return;
   }
-  QProcess dsr;
-  //dsr.setProcessChannelMode(QProcess::MergedChannels);
-  dsr.start(dsrpath, QStringList() << QString("-x")+searchName);
-  dsr.closeWriteChannel();
-  outtext->clear();
-  if (!dsr.waitForFinished()) {
-    outtext->append("Unable to start DSR.");
-    outtext->append(dsr.readAll());
-    outtext->append(dsr.errorString());
-  } else {
-    result->append(dsr.readAll());
-  }
+  QString option = QString(" -x ") + searchName;
+  dsrResulttext.clear();
+  this->runDSR(option, false);
   QVector<QStringList> fraglist;
   fraglist.clear();
-  foreach (QString line, result->split(QRegExp("\n|\r\n|\r"))) {
+  foreach (QString line, dsrResulttext.split(QRegExp("\n|\r\n|\r"))) {
     if (line.isEmpty()){
       continue;
     }
@@ -1345,40 +1415,27 @@ bool DSRGui::listDSRdbFragments(QString fav="None") {
   if (QString("None") == fav) {
     fav = loadFavoriteFragment().toLatin1().toUpper();
   }
-  QString *fraglist = new QString;
   fragmentsList->clear();
-  QProcess dsr;
   fragmentNameTag.clear();
-  //dsr.setProcessChannelMode(QProcess::MergedChannels);
-  dsr.start(dsrpath, QStringList() << "-lc");
-  dsr.closeWriteChannel();
-  if (!dsr.waitForFinished()) {
-    outtext->append(QString(tr("Unable to start DSR.")));
-    outtext->append(QString(tr("Please get the most recent version from https://www.xs3.uni-freiburg.de/research/dsr")));
-    outtext->append(dsr.readAll());
-    outtext->append(dsr.errorString());
-  } else {
-    fraglist->append(dsr.readAll());
-  }
-  QStringList string_list = fraglist->split(QRegExp("\n|\r\n|\r"));
-  if (string_list.last().isEmpty())
-    string_list.removeLast();
-  bool versionOk;
-  versionOk = false;
-  foreach (QString line, string_list) {
+  QString options = " -lc";
+  runDSR(options, true);
+  QStringList frag_str_list = dsrResulttext.split(QRegExp("\n|\r\n|\r"));
+  bool versionOk = false;
+  foreach (QString line, frag_str_list) {
     if (line.contains("Duplicate database entry")) {
       outtext->clear();
-      outtext->append(*fraglist);
+      outtext->append(dsrResulttext);
       return false;
     }
   }
   // in this case no fragment list returned. Hence, we have an error.
-  if (!fraglist->contains(";;")) {
-    outtext->clear();
+  if (!dsrResulttext.contains(";;")) {
+    //outtext->clear();
     outtext->append("Something went wrong with DSR. please tell Daniel Kratzert (dkratzert@gmx.de) about this problem.");
+    outtext->append(dsrResulttext);
     return false;
   }
-  foreach (QString line, string_list) {
+  foreach (QString line, frag_str_list) {
     if (line.isEmpty()){
       continue;
     }
