@@ -588,9 +588,9 @@ void GraphSceene::mouseMoveEvent ( QGraphicsSceneMouseEvent  * mouseEvent ){
    // qDebug()<<"End"<<selEnd;
   }else{	
     // qDebug()<<x<<y;
-    if (!itemAt(x,y)) emit meinstatus(-1);
+    if (!itemAt(x,y,QTransform())) emit meinstatus(-1);
     else{
-      int da = itemAt(x,y)->data(0).toInt(); 
+      int da = itemAt(x,y,QTransform())->data(0).toInt(); 
       emit meinstatus(da);  
     }
   }
