@@ -104,7 +104,7 @@ void HistoryWidget::deleteOne(){
     if (fileName.isEmpty()) return;
     QString fcfname=fileName;
     fcfname.replace(fcfname.size()-3,3,"fcf");
-    if (QMessageBox::Yes==QMessageBox::question ( this, "Delete hisory entry", 
+    if (QMessageBox::Yes==QMessageBox::question ( this, "Delete history entry", 
 			    QString("Do you really whant to delete history files '<b>%1</b>' and '<b>%2</b>'?").
 			    arg(fileName).
 			    arg(fcfname), 
