@@ -20,6 +20,9 @@
 #define HISTORYWIDGET_H
 
 #include <QWidget>
+#if (QT_VERSION >= 0x050000)
+#include <QtWidgets>
+#endif 
 #include <QDateTime>
 #include <QMap>
 #include "itsme.h"
