@@ -22,9 +22,11 @@
 #ifndef fmin
 #define fmin(x, y) (((x) < (y)) ? (x) : (y))
 #endif
-//#ifndef round 
-//#define round(x) (x<0)?ceil((x)-0.5):floor((x)+0.5)
-//#endif
+#if defined _MSC_VER &&  _MSC_VER == 1500
+#ifndef round 
+#define round(x) (x<0?ceil((x)-0.5):floor((x)+0.5))
+#endif
+#endif
 #include <QString>
 #include <QStringList>
 #include <QList>
@@ -259,7 +261,7 @@ typedef struct MyAtom{
   int hidden;
   //! the site occupation factor as it is the file e.g. 11.000
   double sof_org;
-  //! the site occupation factor
+  //! the site occupation factor e.g. 1.0 or 0.5
   double sof;
   //! the fractional Uij
   Matrix uf;
@@ -1286,6 +1288,7 @@ public:
   void fillCell();
   void uniqueInCell();
   void packer(QStringList brauchSymm);
+  void packInLimits(double ami, double ama, double bmi, double bma, double cmi, double cma);//!< Pack inside given limits (eg multiple unit cells)
   void applyLatticeCentro(int gitter);
   void Uf2Uo(const Matrix x, Matrix & y) ;
   void Usym (Matrix x,Matrix sym, Matrix & y);
