@@ -191,7 +191,7 @@ DragDropVersions::DragDropVersions(QString filename, QWidget *parent) :QWidget(p
       else if (insorres.endsWith("ins",Qt::CaseInsensitive)) insorres.replace(QRegExp("ins$",Qt::CaseInsensitive),"res");
 
   current=-1;
-  QDir work=QDir(QString("%1/%2saves/").arg(dn).arg(PROGRAM_NAME));
+  //QDir work=QDir(QString("%1/%2saves/").arg(dn).arg(PROGRAM_NAME));  // unused
   QString saveHistName=QString("%1/%2saves/SAVEHIST").arg(dn).arg(PROGRAM_NAME);
   QFile sahi(saveHistName);
   sahi.open(QIODevice::ReadOnly|QIODevice::Text);
