@@ -65,7 +65,7 @@ public slots:
 	void accept();  
   private:
  int pvindex;
-    CodeEditor *edi;
+    CodeEditor *edi;  //!> Editor for the save history file difference.
     QLabel *pvheader;
     DragDropVersions *dda;
     QString fileName,orginal;
