@@ -136,6 +136,7 @@ float fo,//!< F observed
 void setSCAT(QStringList tok){
   if (tok.size()<16)return;
   int an = mol->getOZ(tok.at(1));
+  if (an<0)return;
   for (int i=0; i<9; i++) {
     ff[an].ab4c[i]=tok.at(2+i).toFloat();
 //    qDebug()<<i+2<<ff[an].ab4c[i];
@@ -151,7 +152,9 @@ void setDISP(QStringList tok){
   if (tok.size()<4)return;
   int an = mol->getOZ(tok.at(1));
   ff[an].fpcu=ff[an].fpmo=ff[an].fpag    = tok.at(2).toFloat();
+  if (tok.size()<4)return;
   ff[an].fppcu=ff[an].fppmo=ff[an].fppag = tok.at(3).toFloat();
+  if (tok.size()<5)return;
   ff[an].mucu=ff[an].mumo=ff[an].muag    = tok.at(4).toFloat();
 
 }
