@@ -83,15 +83,15 @@ QStringList shxToolTips =(QStringList()<<
 "PRIG p[#]\nSets the parameter p for RIGU"<<
 "WIGL del[0.5]\nDisplaces all atoms by distance del"<<
 "RANG angle restraints"<<
-"TANG torsion anghle restraints"<<
+"TANG torsion angle restraints"<<
 "ADDA O2T_999 etc. add atoms to residue so that H-restrains are obeyed."<<
 "STAG torsion angle restraint for staggered"<<
 "NEUT convert x-ray SFAC table to neutrons"<<
 "ABIN n1 n2  including precalculate structure factors"<<
 "ANSC six coefficients\nanisotropic scaling"<<
 "ANSR [0.001] restraint for ANSC "<<
-"NOTR p[170] d[1.9] cremoves torsion angles generated by CONF from the .cif file"<<
-"TWST N[0] specify twin component used for completeness and friedel statictics"<<
+"NOTR p[170] d[1.9] removes torsion angles generated by CONF from the .cif file"<<
+"TWST N[0] specify twin component used for completeness and Friedel statistics"<<
 "BEDE atom1 atom2 r A U1 U2"<<
 "LONE m atomnames A U1 U2 r phi\nphi required for m = 2, 3, 7, 9, and 12"//<<
 );
