@@ -35,7 +35,7 @@
 #ifndef fmin
 #define fmin(x, y) (((x) < (y)) ? (x) : (y))
 #endif
-#ifndef round
+#if defined _MSC_VER &&  _MSC_VER == 1500
 #define round(x) (x<0?ceil((x)-0.5):floor((x)+0.5))
 #endif
 #undef vc7hack1
@@ -96,6 +96,7 @@ public:
   QString dirName; //!< Full path of the currently opened file (including file name).
   void setFocus(bool b){focusSet=b;}
   bool isFocusSet() {return focusSet;}
+  int getFvarCntr(int fvar);//!< returns the number of uses of a free variable.
   int firstAtomLine;
   
 public slots:
@@ -146,7 +147,7 @@ public slots:
   void extraSettings();//!<A dialog to add/edit exteral programs started from ShelXle with or without arguments.
   void exportCoordinates();//!<Exports all visible atoms to an extra file. 
   void exportFMaps();
-  bool fileSave();//!<saves the editor content to the current file.
+  bool fileSave(bool spell=true, bool loadafter=true);//!<saves the editor content to the current file. @param spell disable spell checking during save @param loadafter disable reloading of file.
   bool fileSaveAs();//!<Saves the editor content to a specified file.
   void fillCell();//!<Uses symmetry until the unit cell box is full.
   void findInStructure(const QString &info);//!<the atom with the matching orgiginal line gets centered and selected.@param info original line content.
@@ -157,6 +158,7 @@ public slots:
   void findResi(QString);//!<Searches a Residue via a string like "RESI 22 ALA" or "RESI ALA 22" in the editor and selects all atoms with the same residue number (eg: 22).
   void findText();//!<Find functionality of search and replace in the editor.
   void findText2();//!<Find functionality of search in the list view.  
+  void finXL();//!Finish XL by name.fin 
   void fixIt();//!< Fix some parameters from being refined.
   void foversusfc();//!< Shows a duialog to analyse and omit outlier reflections.
   void fuse();//!< show only the asymetric unit.
@@ -175,6 +177,17 @@ public slots:
   void insertBind();//!< inserts a BIND instruction into the file.
   void insertFree();//!< inserts a FREE instruction into the file.
   void insertList6();//!< inserts a LIST 6 instruction into the file.
+  void insertDFIX(double value, double esd, QList<MyAtom> selected, QString resiSpec=""); //!< Insert DFIX restraint into ins file
+  void insertDANG(double value, double esd, QList<MyAtom> selected, QString resiSpec=""); //!< Insert DANG restraint into ins file
+  void insertFLAT(double esd, QList<MyAtom> selected, QString resiSpec=""); //!< Insert FLAT restraint into ins file
+  void insertEXYZ(QList<MyAtom> selected, QString resiSpec=""); //!< Insert EXYZ restraint into ins file
+  void insertEADP(QList<MyAtom> selected, QString resiSpec=""); //!< Insert EADP restraint into ins file
+  void insertDELU(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec=""); //!< Insert DELU restraint into ins file
+  void insertSIMU(double esd1, double esd2, double dmax, QList<MyAtom> selected, QString resiSpec=""); //!< Insert SIMU restraint into ins file
+  void insertISOR(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec=""); //!< Insert ISOR restraint into ins file
+  void insertRIGU(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec=""); //!< Insert RIGU restraint into ins file
+  void insertCHIV(double vol, double esd1, QList<MyAtom> selected, QString resiSpec=""); //!< Insert CHIV restraint into ins file
+  void insertANIS(QList<MyAtom> selected); //!< Insert ANIS for selected atoms
   void invert();//!< inverts the structure and changes ot the right enantiomorph space group.
 //  inline int Intersect( double& vm, double& vp ){ return vm*vp <= 0.0 && (vm<0.0 || vp<0.0); }//!<
   void isUpToDate(QNetworkReply* antwort);//!< Interpretes the network reply for the check for updates (manual version)
@@ -196,17 +209,7 @@ public slots:
   void openRecentFile();//!< opens a recently used file
   void openSaveHistory();//!< sows the save history dialog
   void outputIsVisible(bool);//!< is Output really visble
-  void insertDFIX(double value, double esd, QList<MyAtom> selected, QString resiSpec=""); //!< Insert DFIX restraint into ins file
-  void insertDANG(double value, double esd, QList<MyAtom> selected, QString resiSpec=""); //!< Insert DANG restraint into ins file
-  void insertFLAT(double esd, QList<MyAtom> selected, QString resiSpec=""); //!< Insert FLAT restraint into ins file
-  void insertEXYZ(QList<MyAtom> selected, QString resiSpec=""); //!< Insert EXYZ restraint into ins file
-  void insertEADP(QList<MyAtom> selected, QString resiSpec=""); //!< Insert EADP restraint into ins file
-  void insertDELU(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec=""); //!< Insert DELU restraint into ins file
-  void insertSIMU(double esd1, double esd2, double dmax, QList<MyAtom> selected, QString resiSpec=""); //!< Insert SIMU restraint into ins file
-  void insertISOR(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec=""); //!< Insert ISOR restraint into ins file
-  void insertRIGU(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec=""); //!< Insert RIGU restraint into ins file
-  void insertCHIV(double vol, double esd1, QList<MyAtom> selected, QString resiSpec=""); //!< Insert CHIV restraint into ins file
-  void insertANIS(QList<MyAtom> selected); //!< Insert ANIS for selected atoms
+  void packInLimits();//!< Pack inside given limits (eg multiple unit cells)
 //  bool peakcomp(MyAtom &a1,MyAtom &a2);
   void raiseTaff();// show visual refinement output
   void raiseTaz();// show text refinement output
@@ -235,6 +238,7 @@ public slots:
   void schnittart(int trunc);//!< the truncation type of the electron density maps changes to trunc @param trunc new truncation type.
   void sdm();//!< the shortest distance matrix is (re)calculated and the structure is grown
   void selectInStructure(const QString &info);//!< selects all atoms found in selected text in the structure @params info seleted text. 
+  void shredCIF();//!< runs shredcif and loads ins/res file
   void sortSelectedRegion();//!< sorts all atoms found in selected text in the structure @params info seleted text.
   void selectParts();//!< selects atoms for 'Part Selector'
   void setShelxlOptions();//!< sets path and command line options for ShelXl executable.
@@ -398,6 +402,7 @@ private:
   QAction *zm_stereo, *pe_stereo, *xe_stereo, *an_stereo, *hw_stereo, *no_stereo; 
   QAction *fcvsfoAct, *calcAct;
   QAction *soact;
+  QString shredCIFPath;
   QAction *backColor,*labelColor;
   QVBoxLayout *lt;
   QToolButton  *zoomIn,*zoomOut;
@@ -435,11 +440,11 @@ private:
   QComboBox *resiFinder;
   QLabel *lineColumn;
   QGroupBox *suchbox2,*suchbox,*navibox,*refineButtonBox,*refineButtonBox2;
-  QPushButton *stoppRefinement;
+  QPushButton *stoppRefinement,*finishRefinement;
   QPushButton *loadRes;
   QPushButton *withdraw;
   
-  QPushButton *stoppRefinement2;// this is for infotainment dock
+  QPushButton *stoppRefinement2,*finishRefinement2;// this is for infotainment dock
   QPushButton *loadRes2;
   QPushButton *withdraw2;
   QToolButton *spellCheckact,*spellCheckact2;
